import { Component } from '@angular/core';

import { UserService } from '../user.service';
import { User } from '../user.model';
import { MatSnackBar } from '@angular/material/snack-bar';

@Component({
  selector: 'app-register',
  templateUrl: './register.component.html',
  styleUrls: ['./register.component.css']
})
export class RegisterComponent {
  user: User = {
    username: '',
    email: '',
    password: '',
    profilePicture: '',
    role: 'USER' // Default role
  };

  constructor(private userService: UserService, private snackBar: MatSnackBar) {}

  register(): void {
    this.userService.createUser(this.user).subscribe(
      () => {
        this.user = {email: "", profilePicture: "", role: "", username: '', password: '' };
        this.snackBar.open('User created successfully!', 'Close', {
          duration: 3000,
          panelClass: ['custom-snack-bar'],
        });
      },
      (error) => {
        console.error('Error creating user:', error);
        this.snackBar.open('Failed to create user.', 'Close', {
          duration: 3000,
          panelClass: ['custom-snack-bar-error'],
        });
      }
    );
  }
}


