import { Component, Input, OnInit } from '@angular/core';
import { Review } from '../../../model/review.model';
import { Movie } from '../../../model/movie.model';
import { ReviewService } from '../../../services/review.service';
import {UserService} from "../../login-page/user.service";
import {MatSnackBar} from "@angular/material/snack-bar";

@Component({
  selector: 'app-review',
  templateUrl: './review.component.html',
  styleUrls: ['./review.component.css']
})
export class ReviewComponent implements OnInit {
  @Input() movie!: Movie;
  @Input() review!: Review | null;

  newRating: number | null = null;
  newComment: string = '';

  constructor(private reviewService: ReviewService, private userService: UserService, private snackBar: MatSnackBar) { }

  submitReview(): void {
    const review: Review = {
      movieId: this.movie.movieId!,
      rating: this.newRating!,
      comment: this.newComment,
      userName: this.userService.getUserName()!,
      userId: this.userService.getUserId()!,
      reviewDate: new Date()
    };

    this.reviewService.postReview(review).subscribe({
      next: () => {
        console.log('Review submitted successfully');
        this.newRating = null;
        this.newComment = '';
        this.snackBar.open('Review submitted successfully!', 'Close', {
          duration: 3000,
          panelClass: ['custom-snack-bar'],
        });
      },
      error: (error) => {
        console.error('Error submitting review:', error);
        this.snackBar.open('Error submitting review. Please try again.', 'Close', {
          duration: 3000,
          panelClass: ['custom-snack-bar-error'],
        });
      }
    });
  }


  ngOnInit(): void {
  }

  protected readonly Math = Math;
}
