import {Component, OnInit} from '@angular/core';
import {Movie} from "../../model/movie.model";
import {Review} from "../../model/review.model";
import {MovieService} from "../../services/movie.service";
import {ReviewService} from "../../services/review.service";
import {UserService} from "../login-page/user.service";

@Component({
  selector: 'app-user-page',
  templateUrl: './user-page.component.html',
  styleUrls: ['./user-page.component.css']
})
export class UserPageComponent implements OnInit {
  movies: Movie[] = [];
  reviews: Review[] = [];
  joiningDate: string = "24/03/2025";
  userName: string | null = "User Name";
  ratingsCount: number = 0;
  reviewsCount: number = 0;

  constructor(private movieService: MovieService, private reviewService: ReviewService, private userService: UserService) {}

  ngOnInit(): void {
    this.loadMovies();
    this.getUserReviews();
    this.userName = this.userService.getUserName();
  }

  getUserReviews(): void {
    const userId = this.userService.getUserId();
    if (userId) {
      this.reviewService.getUserReviews(this.userService.getUserId()!).subscribe((data: Review[]) => {
        this.reviews = data;
        this.countReviews()
        this.getUserReviews()
      },
        (error) => {
          console.error('Error fetching reviews:', error);
        });
    } else{
      console.log("User has no reviews");
    }
  }

  loadMovies(): void {
    this.movieService.getAllMovies().subscribe(movies => {
      this.movies = movies;
    });
  }

  getReviewsForMovie(movieId: string): Review | null {
    return this.reviews.find(review => review.movieId === movieId) || null;
  }


  countReviews(): void {
    this.ratingsCount = 0;
    this.reviewsCount = 0;

    this.reviews.forEach((review: Review) => {
      if (review.rating != null) {
        this.ratingsCount++;
      }
      if (review.comment != null && review.comment != "" ) {
        this.reviewsCount++;
      }
    })
  }
}
