import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { Actor } from '../model/actor.model';

@Injectable({
  providedIn: 'root'
})
export class ActorService {
  private apiUrl = 'http://localhost:8080/api/actors';

  constructor(private http: HttpClient) {}

  // Method to create a new actor
  createActor(actor: Actor): Observable<Actor> {
    return this.http.post<Actor>(this.apiUrl, actor);
  }

  // Method to get all actors
  getAllActors(): Observable<Actor[]> {
    return this.http.get<Actor[]>(this.apiUrl);
  }

  // Method to get an actor by ID
  getActorById(actorId: string): Observable<Actor> {
    return this.http.get<Actor>(`${this.apiUrl}/${actorId}`);
  }

  // Method to update an actor
  updateActor(actorId: string, actor: Actor): Observable<Actor> {
    return this.http.put<Actor>(`${this.apiUrl}/${actorId}`, actor);
  }

  // Method to delete an actor
  deleteActor(actorId: string): Observable<void> {
    return this.http.delete<void>(`${this.apiUrl}/${actorId}`);
  }
}
