import { Injectable } from '@angular/core';
import {HttpClient, HttpErrorResponse} from '@angular/common/http';
import {catchError, Observable, throwError} from 'rxjs';
import { Movie } from '../model/movie.model';

@Injectable({
  providedIn: 'root'
})
export class MovieService {
  private apiUrl = 'http://localhost:8080/api/movies';

  constructor(private http: HttpClient) { }

  createMovie(movie: Movie): Observable<void> {
    return this.http.post<void>(this.apiUrl, movie).pipe(
      catchError(this.handleError('creating movie'))
    );
  }

  updateMovie(movie: Movie): Observable<Movie> {
    return this.http.put<Movie>(this.apiUrl, movie).pipe(
      catchError(this.handleError('updating movie'))
    );
  }

  deleteMovie(movieId: string, userId: string): Observable<void> {
    return this.http.delete<void>(`${this.apiUrl}/${movieId}/${userId}`).pipe(
      catchError(this.handleError('deleting movie'))
    );
  }

  getAllMovies(): Observable<Movie[]> {
    return this.http.get<Movie[]>(this.apiUrl).pipe(
      catchError(this.handleError('fetching movies'))
    );
  }

  getMovieById(id: string): Observable<Movie> {
    return this.http.get<Movie>(`${this.apiUrl}/${id}`).pipe(
      catchError(this.handleError('fetching movie by ID'))
    );
  }

  private handleError(action: string) {
    return (error: HttpErrorResponse) => {
      console.error(`Error ${action}:`, error.message);
      return throwError(error.error || 'Server error');
    };
  }
}
