import {Component, HostListener, OnInit} from '@angular/core';
import { UserService } from '../../features/login-page/user.service';
import { Router } from '@angular/router';
import {MatMenuPanel} from "@angular/material/menu";

@Component({
  selector: 'app-header',
  templateUrl: './header.component.html',
  styleUrls: ['./header.component.css']
})
export class HeaderComponent implements OnInit  {
  username: string | null = null;
  userRole: string | null = null;
  isMobile: boolean = false;

  @HostListener('window:resize', ['$event'])
  onResize(event: any) {
    this.isMobile = window.innerWidth < 768;
  }

  onNavigateHome() {
    this.router.navigate(['/']); // Navigate to the landing page
  }

  constructor(private userService: UserService, private router: Router) {
    this.isMobile = window.innerWidth < 768;
  }

  ngOnInit(): void {
    this.userService.username$.subscribe(username => {
      this.username = username;
    });
    this.userService.userRole$.subscribe(userRole => {
      this.userRole = userRole;
    });
  }

  onLogOut(): void {
    this.userService.logoutUserStatusUpdate();
    this.router.navigate(['/']);
  }

  onLogin() {
    this.router.navigate(['/login']);
  }

  onSignUp() {
    this.router.navigate(['/login']);
  }
}

